#!/usr/bin/env python

# --
#                 - Mellanox Confidential and Proprietary -
#
# Copyright (C) Jan 2017, Mellanox Technologies Ltd.  ALL RIGHTS RESERVED.
#
# Except as specifically permitted herein, no portion of the information,
# including but not limited to object code and source code, may be reproduced,
# modified, distributed, republished or otherwise exploited in any form or by
# any means for any purpose without the prior written permission of Mellanox
# Technologies Ltd. Use of software subject to the terms and conditions
# detailed in the file "LICENSE.txt".
# --
# Author: Ahmed Awwad   ahmadaw@mellanox.com -- created: 2017/June

# Python Imports
import sys
# local imports
from command_sdk import CommandSdk
import neohost_sdk_constants as NC
from neohost_sdk_exception import NeohostSdkException


class GetDeviceVPD(CommandSdk):
    """
    This class to get device vpd
    """

    def __init__(self):
        """
        Constructor for GetDeviceVPD
        """
        super(GetDeviceVPD, self).__init__()
        self.__devUid = None
        self.__attrMask = None

    def addOptions(self):
        """
        add options
        """
        super(GetDeviceVPD, self).addOptions()
        self._cmdParser.add_option("--dev-uid", dest="devUid",
                                   help=NC.HELP_DEV_UID,
                                   default=None)
        self._cmdParser.add_option("--attr-mask", dest="attrMask",
                                   help=NC.HELP_ATTR_MASK,
                                   type="int",
                                   default=0)

    def parseOptions(self):
        """
        parse options
        """
        super(GetDeviceVPD, self).parseOptions()
        self.__devUid = self._options.devUid
        self.__attrMask = self._options.attrMask

    def prepareRequest(self):
        """
        Prepare request before post it . add method and module.
        """
        super(GetDeviceVPD, self).prepareRequest()
        self.request[NC.ATTR_METHOD] = NC.METHOD_GET_DEVICE_VPD
        self.request[NC.ATTR_MODULE] = NC.MODULE_MFT_FW
        self.request[NC.ATTR_PARAMS] = {NC.PARAM_DEV_UID: self.__devUid,
                                        NC.PARAM_ATTR_MASK: self.__attrMask}

    def validateOptions(self):
        """
        Validate Options
        """
        super(GetDeviceVPD, self).validateOptions()
        if not self.__devUid:
            raise NeohostSdkException("-E- %s" % NC.MISSING_DEV_UID)


if __name__ == "__main__":
    rc = GetDeviceVPD.main()
    sys.exit(rc)
